Chapter 4: Inversions
=====================

In chapter 4, we use *Inversions* to reconstruct complex source galaxies on pixelized grids.

You can start the tutorials right now by going to `our binder <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/HEAD>`_
and navigating to the folder ``notebooks/howtolens/chapter_4_inversions``. They are also on the `autolens_workspace <https://github.com/Jammy2211/autolens_workspace>`_.

The chapter contains the following tutorials:

`Tutorial 1: Pixelizations <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_4_inversions/tutorial_1_pixelizations.ipynb>`_
- Creating a pixel-grid in the source-plane.

`Tutorial 2: Mappers <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_4_inversions/tutorial_2_mappers.ipynb>`_
- How a pixelizations maps source-pixels to image-pixels.

`Tutorial 3: Inversions <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_4_inversions/tutorial_3_inversions.ipynb>`_
- Inverting the mappings to reconstruct the source's light.

`Tutorial 4: Bayesian Regularization <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_4_inversions/tutorial_4_bayesian_regularization.ipynb>`_
- Smoothing the source within a Bayesian framework.

`Tutorial 5: Borders <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_4_inversions/tutorial_5_borders.ipynb>`_
-Preventing highly demagnified image-pixels ruining the inversion.

`Tutorial 6: Lens Modeling  <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_4_inversions/tutorial_6_lens_modeling.ipynb>`_
- How to use inversions to fit a lens model.

`Tutorial 7: Adaptive Pixelization <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_4_inversions/tutorial_7_adaptive_pixelization.ipynb>`_
- An Voronoi pixelization which adapts to the mass model's magnification.

`Tutorial 8: Pipeline Inversion <https://github.com/Jammy2211/autolens_workspace/blob/master/notebooks/howtolens/chapter_4_inversions/tutorial_8_pipeline_runner.ipynb>`_
- An example pipeline which uses an inversion.